chordtools.divide_chord_by_diatonic_pitch_number
================================================

.. autofunction:: abjad.tools.chordtools.divide_chord_by_diatonic_pitch_number.divide_chord_by_diatonic_pitch_number
